@@ -1,17 +1,22 @@
 # ---------------------------------------------------------------------------
 # mockify/mock/__init__.py
 #
-# Copyright (C) 2018 - 2020 Maciej Wiatrzyk
+# Copyright (C) 2019 - 2020 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
 #
 # This file is part of Mockify library and is released under the terms of the
 # MIT license: http://opensource.org/licenses/mit-license.php.
 #
 # See LICENSE for details.
 # ---------------------------------------------------------------------------
-from ._base import MockInfo, BaseMock
-from ._mock import Mock
-from ._function import FunctionMock
-from ._factory import MockFactory
-from ._abc_mock import ABCMock
+"""Module containing types used to mock things.
 
-__all__ = ['MockInfo', 'BaseMock', 'Mock', 'FunctionMock', 'MockFactory', 'ABCMock']
+These can be considered as frontends on top of Mockify's core
+functionality.
+"""
+
+from ._abc_mock import ABCMock
+from ._factory import MockFactory
+from ._function import FunctionMock
+from ._mock import Mock
+
+__all__ = ['Mock', 'FunctionMock', 'MockFactory', 'ABCMock']
